#
# spec file for package scribus
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) Peter Linnell and 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           scribus
Version:        1.4.7
Release:        lp150.1.1
Summary:        Open Source Page Layout and Desktop Publishing (DTP)
License:        GPL-2.0+
Group:          Productivity/Publishing/Other
Url:            http://www.scribus.net/
Source0:        http://sourceforge.net/projects/%{name}/files/%{name}/%{version}/%{name}-%{version}.tar.xz
Source1:        %{name}-icon24.png
Source2:        %{name}-icon32.png
Source3:        %{name}-icon64.png
Source4:        %{name}-icon128.png
Source5:        %{name}-icon256.png
Source6:        %{name}.appdata.xml
# PATCH-FIX-OPENSUSE
Patch:          hunspell-1.6.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  cairo-devel
BuildRequires:  cmake >= 2.6.0
BuildRequires:  cups-devel
BuildRequires:  fdupes
BuildRequires:  fontconfig-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  hunspell-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libpodofo-devel
BuildRequires:  libqt4-devel >= 4.6.0
BuildRequires:  libtiff-devel
BuildRequires:  libxml2-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files


%if 0%{?suse_version} 
Requires:       ghostscript-library
Requires:       python-imaging
Requires:       tk
Suggests:       AdobeICCProfiles
Suggests:       Uniconvertor
%endif


%description
Scribus is a open source page layout program which
produces commercial grade output in PDF and Postscript, primarily,
though not exclusively, for Linux.

While the goals of the program are ease of use and simple
easy-to-understand tools, Scribus support for professional
publishing features, such as CMYK and spot colors, easy PDF creation,
Encapsulated Postscript import and export and creation of color
separations.

%package devel
Summary:        Open Source Page Layout / Desktop Publishing (DTP)
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       freetype2-devel
Requires:       glibc-devel
Requires:       libstdc++-devel
Requires:       zlib-devel

%description devel

This package provides the development headers for scribus. It is most useful 
for developing scribus plugins.

%prep

%setup -q
%patch -p1

%build
# Delete non-free colour swatches (bnc#763586)
rm resources/swatches/givelife_colors_license.rtf
rm resources/swatches/GiveLife_Color_System*.xml
# All .eps swatches come with the same non-free license by dtp studio Oldenburg.
rm resources/swatches/*.eps
rm resources/swatches/dtp-studio-free-palettes-license.rtf

export CXXFLAGS="%{optflags} -fno-strict-aliasing"
export CFLAGS="$CXXFLAGS -fno-strict-aliasing"

mkdir build
pushd build
cmake \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  %if "%{_lib}" == "lib64"
  -DWANT_LIB64=1 \
  %endif
  -DWANT_CAIRO=1 \
  -DCMAKE_BUILD_WITH_INSTALL_RPATH=FALSE \
  -DCMAKE_SKIP_RPATH=TRUE \
  -DWANT_HUNSPELL=1 \
   ../

make %{_smp_mflags}

%install

pushd build
make install DESTDIR=%{buildroot}

popd

# install hi-res icons for better appearance on gnome-shell
install -D -m 0644 %{S:1} %{buildroot}%{_datadir}/icons/hicolor/24x24/apps/%{name}.png
install -D -m 0644 %{S:2} %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
install -D -m 0644 %{S:3} %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/%{name}.png
install -D -m 0644 %{S:4} %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
install -D -m 0644 %{S:5} %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png

%if 0%{?suse_version}
%suse_update_desktop_file -r -i %{name} Qt Office Publishing WordProcessor

%endif

%fdupes -s %{buildroot}%{_includedir}/%{name}/

# INSTALL APPSTREAM METAINFO (SOURCE6)
install -Dm0644 %{S:6} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

#update the mime database

%post
%mime_database_post
%desktop_database_post
%icon_theme_cache_post

%postun
%mime_database_postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%{_bindir}/scribus
%{_mandir}/man?/*.*
%{_mandir}/*/man?/*.*
%{_libdir}/scribus
%{_datadir}/mime/packages/scribus.xml
%{_datadir}/scribus
%{_datadir}/doc/scribus
%{_datadir}/applications/%{name}.desktop
# This should be owned by filesystem or man, but there are only scribus files:
%lang(pl) %dir %{_mandir}/pl
%lang(pl) %{_mandir}/pl/man1 
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml

%files devel
%defattr(-,root,root)
%{_includedir}/scribus

%changelog
* Tue May  1 2018 wbauer@tmo.at
- Add back hunspell-1.6.patch, it's still needed as the current
  version still only supports hunspell up to 1.4 but Tumbleweed and
  Leap 15.0 have 1.6
* Sun Apr 29 2018 plinnell@opensuse.org
- drop hunspell-1.6.patch fixed uptream
- lots of spec file cleanups
* Sat Apr 28 2018 plinnell@opensuse.org
- Update to 1.4.7 - likely last release from 1.4.x stable branch
- Stability and bugfix release
- Updated UI translations
- See: https://bugs.scribus.net/changelog_page.php?version_id=96
  for complete list.
* Tue Mar 27 2018 wbauer@tmo.at
- Add hunspell-1.6.patch to fix spellchecking support in Tumbleweed
  and Leap 15.0
* Thu Jan  4 2018 wbauer@tmo.at
- remove libQtWebKit-devel build requirement, it seems not to be
  used/needed at all
* Fri Aug 11 2017 pgajdos@suse.com
- remove dependency on aspell, scribus seem to use hunspell
  [bsc#1052965]
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Tue Nov 15 2016 wbauer@tmo.at
- Use shared-mime-info macros (boo#979301)
- Remove version check for > 11.3, earlier versions are not
  supported any more
* Wed Aug 10 2016 badshah400@gmail.com
- Fixup scribus.appdata.xml file
  + Shorten name to just "scribus".
  + Use images from github repository as appstream fails to load
    images from https://wki.scribus.net.
  + Improve a caption.
  + Fix height of screenshot 2.
* Thu Jul 28 2016 badshah400@gmail.com
- Add scribus.appdata.xml file and install it to the appdata dir;
  this makes scribus appear in appstores like GNOME Software and
  KDE Discover.
* Fri Mar 18 2016 alarrosa@suse.com
- Added an fdupes call to symlink duplicate files installed
  under /usr/share/. This reduces the installed size in around 20 Mb.
* Mon Jan 11 2016 plinnell@opensuse.org
- Update to 1.4.6
  + See http://bugs.scribus.net/changelog_page.php?version_id=92
* Thu May 29 2014 plinnell@opensuse.org
- Update to 1.4.4
- Drop python-version.diff it is upstream.
  + PDF/X-1a export.
  + The Barcode plug-in has been updated to reflect
  the latest changes in the underlying Barcode Writer
  in Pure PostScript (BWIPP).
  + The Autoquote script has been rewritten and enhanced.
  It now provides more options and adds thin spaces to French texts
  where appropriate.
  + A script to align images in frames has been added.
  + Full support of the OpenICC Directory Proposal
  (http://www.oyranos.org/wiki/index.php?title=OpenIccDirectoryProposal).
  + The handling of transparencies in Photoshop-generated TIFF files
  has been improved.
  + Page borders can now act as guides (and thus be used for
  snapping of items).
  + The CMYK color palette created by the Newspaper Association
  of America  (NAA) for newspaper advertisements has been
  integrated into Scribus.
  + A new color palette for professional geographers has been added.
  + Export to various bitmap formats has been re-enabled on Mac OS X.
  + Several issues related to the user interface and canvas display
  have been resolved.
  + Adjustments for Windows 8.x.
  + An issue with the spellchecker, resulting in a crash,
  has been resolved.
  + Documentation and translation updates and improvements.
  +For a complete list of changes see:
  http://bugs.scribus.net/view_all_bug_page.php?filter=99610
  and http://lists.scribus.net/pipermail/scribus-commit.
* Thu Apr 17 2014 hrvoje.senjan@gmail.com
- Added python_version.diff: fixes build with cmake 3.0
* Thu Aug 22 2013 mrdocs@opensuse.org
- Update to version 1.4.2
  + The Barcode Writer has been updated and supports many more
    barcodes, including QR.
  + The Galaxy Gauge™ color matching system and color tools have
    been included.
  + New color palettes from government agencies (Canada,
    Germany, The Netherlands, United Kingdom) have been included.
  + More Open Source color palettes have been included.
  + Improvements to the build system.
  + Improvements to the Preflight Verifier.
  + The A4 page size limit of TeX-rendered graphics in Render
    Frames has been removed.
  + The Short Words plug-in now supports Danish.
  +  Many updates to the Online Manual.
-  Most important bugfixes:
- Disabled hyphenation on some Linux distributions is working again.
- Some unit conversion issues have been fixed.
- Display issues related to Ubuntu's Unity interface have been fixed.
- Some fixes to wrong or irritating UI behavior.
- Memory management in connection with the new Hyphenator has
  been optimized.
- Issues with the Clang compiler have been fixed.
- Scribus now supports Pillow as an alternative to the Python Imaging Library.
- Many translation updates.
* Mon Jan 14 2013 mrdocs@opensuse.org
- Update to version 1.4.2:
  - New feature - hunspell based spell checker
  - UI and Document Updates and translation updates
  - Scribus will look for existing dictionaries on the system
    it is installed already installed by hunspell packages or
    LibreOffice. New dictionaries are downloadable directly from
    within Scribus Preferences via freedesktop.org.
    The spellchecker now also works within the Story Editor.
  - Stability and other minor fixes
  - Complete versioned changelog:
    http://bugs.scribus.net/changelog_page.php?version_id=84
* Fri Jul  6 2012 dmueller@suse.com
- fix build for older distros
* Mon Jun 25 2012 badshah400@gmail.com
- Install hi-res icons in the hicolor icon directory for better
  appearance on desktop menu, specifically on the gnome-shell; add
  BuildRequires: hicolor-icon-theme for this purpose.
* Wed May 23 2012 badshah400@gmail.com
- Delete non-free colour swatches (givelife and dtp-studio) from
  the package (bnc#763586)
* Wed May 23 2012 mrdocs@opensuse.org
- drop fdupes in %%datashare it breaks the help browser
- shorten the -devel description
* Mon May 21 2012 badshah400@gmail.com
- Add back aspell and liblcms2-devel BuildRequires: these got
  removed during the previous change by mistake.
* Sat May  5 2012 badshah400@gmail.com
- Update to version 1.4.1:
  + Many bugs fixed since 1.4.0 (see ChangeLog file installed in
    /usr/share/doc/scribus/)
  + Addition of the GiveLife Color System(R) swatch palettes
    (www.givelifecolorsystem.com), license in the swatches
    directory.
  + Updates to resolve small canvas interaction issues
  + Corrections to both bitmap and SVG image import issues
  + Addition of undo steps for path operations and page moving
  + Corrections to some master page behaviour
  + Fixes for text editing issues
  + Enhancements to scripter
  + Translation updates
  + The Italian version of the help documents has been updated
    significantly
  + Relocation of profiles and swatches to the share directory of
    Unix-like systems (linux, OS X, etc) to fit in with the file
    system recommendations
- Added build requirement on fdupes to link duplicate files
- Install desktop menu for application
- Changes from version 1.4.0:
  + Many bugs fixed since 1.4.0rc6 (see ChangeLog file installed
    in /usr/share/doc/scribus/).
* Fri Jan 20 2012 toddrme2178@gmail.com
- Fixed aspell detection
- Added lcms2 buildrequires
* Mon Jan  2 2012 adrian@suse.de
- update to final 1.4.0 release
- use xz compressed tar ball
* Tue Dec  6 2011 coolo@suse.com
- scribus is GPL-2.0+
* Wed Oct 26 2011 coolo@suse.com
- merged KDF again
* Wed Oct 19 2011 mrdocs@opensuse.org
-updated to 1.4.0.rc6
-last RC before 1.4.0 final
  +documentation updates, bug fixes and translation updates
  +http://scribus.net/svn/Scribus/branches/Version135/Scribus/ChangeLog
  for versioned changelog
* Mon Aug 15 2011 idonmez@novell.com
- Fix build and use %%{_smp_mflags}
* Wed Aug 10 2011 toddrme2178@gmail.com
- Fixed language file identification
  - Removed redundant buildrequires
  - Cleaned up spec file formatting
* Sat Jun 18 2011 mrdocs@opensuse.org
-update to 1.4.0.rc5
  + more bug fixes and translation updates
  see http://bugs.scribus.net/changelog_page.php?version_id=68
  for versioned changelog
* Sun Apr 10 2011 mrdocs@opensuse.org
-update to 1.4.0.rc3
  + more bug fixes and translation updates
  see http://bugs.scribus.net/changelog_page.php?version_id=68
  for versioned changelog
* Tue Mar  8 2011 mrdocs@opensuse.org
-update to 1.4.0.rc2
  + more bug fixes and translation updates
  see http://bugs.scribus.net/changelog_page.php?version_id=68
  for versioned changelog
* Fri Feb 18 2011 mrdocs@opensuse.org
-remove some old versioning cruft from spec file
* Fri Feb 18 2011 mrdocs@opensuse.org
- update to 1.4.0.rc1 1.4.0 is new stable branch
  +40+ bugs fixed see:
  http://bugs.scribus.net/changelog_page.php?version_id=68 for
  versioned change log details
- Add Obsoletes/Provides for scribus-templates for those upgrading
  from 1.3.3.14, former stable.  1.4.0 has new
  and many additional templates included by default
* Sat Jan 15 2011 mrdocs@opensuse.org
- disable parallel build by removing %%jobs macro, it caused OOMs
  during build.
* Mon Dec 27 2010 dmueller@suse.de
- fix build
* Tue Dec 14 2010 mrdocs@opensuse.org
- spec file clean-ups from darix and remove all non-Suse related bits
* Thu Dec  9 2010 mrdocs@opensuse.org
- 1.3.9 release
  + 60+ bug fixes
  + addtional templates
* Thu Mar 25 2010 mrdocs@opensuse.org
- update to 1.3.3.14
- drop the implicit patch as its now upstream
* Fri Jul 31 2009 coolo@novell.com
- fix build
* Tue Apr 28 2009 mrdocs@opensuse.org
- drop fdupes it breaks the help browser
- update to 1.3.3.13
- make %%jobs can break builds just use make
* Mon Dec  8 2008 dmueller@suse.de
- update to 1.3.3.12 (released tarball):
  * Several fixes and improvements to text frames and the Story Editor.
  * Some additional scripts have been added to enhance functionality.
  * More translation and documentation updates.
  * Several fixes to protect against possible crashes.
  * Improvements to the Scripter to enable more features.
* Thu Oct  9 2008 meissner@suse.de
- added stdlib.h, string.h
- run %%fdupes
* Mon Jun  2 2008 crrodriguez@suse.de
- needs fno-strict-aliasing
* Wed Apr 16 2008 dmueller@suse.de
- update to 1.3.3.12svn:
  * http://bugs.scribus.net/changelog_page.php
- add help files back (bnc#379906)
* Mon Apr 14 2008 dmueller@suse.de
- fix build against cmake 2.6
- sync buildrequires with the community package
* Sun Jan 13 2008 dmueller@suse.de
- update to 1.3.3.11:
  * Special characters in plain text files aren't imported
  correctly
  * Change text string in PDF export dialog
* Tue Jan  8 2008 stbinner@suse.de
- update to 1.3.3.10, many bugfixes - for details see ChangeLog
* Wed Jun 27 2007 dmueller@suse.de
- build against cmake to fix various issues
* Wed Jun 13 2007 ltinkl@suse.cz
- update to 1.3.3.9 bugfix release
  - many bugfixes
  - more translation updates
  - improvements to the SVG importer
  - improvements to PDF forms
- update to 1.3.3.8
  - many bugfixes
  - more translation updates
  - improvements to the SVG importer
  - improvements to the Open Document Draw importer
  - improvements to PDF forms
* Mon Apr 23 2007 pgajdos@suse.cz
- fixed doc paths in spec file
* Mon Mar 12 2007 pgajdos@suse.cz
- fixed gcc warnings in beta version:
  * program uses possibly exploitable format strings
    (format-not-literal.patch)
  * program compares a char* pointer with string literal
    (string-literal-comparsion.patch)
  * added CFLAG -fno-strict-aliasing inside scribus.spec
* Thu Mar  8 2007 pgajdos@suse.cz
- fixed 'warning: comparsion with string literal' (#233016, #228963)
- string-literal-comparsion.patch
* Sun Jan 28 2007 stbinner@suse.de
- Updated to bugfix release 1.3.3.7
* Thu Nov  9 2006 sbrabec@suse.cz
- Fixed python detection (#213668).
* Sat Nov  4 2006 stbinner@suse.de
- fix build for < 10.1
* Wed Oct 18 2006 sbrabec@suse.cz
- Updated to version 1.3.3.4:
  * Purely a bug fix release.
  * Translations updated.
* Tue Aug  8 2006 stbinner@suse.de
- update to version 1.3.3.3 "stable usable development version"
  * Fix borked color names and wrong Bitstream Vera rendering
  * Many crash und other minor bug fixes
  * Several translation updates
* Thu Jul 13 2006 stbinner@suse.de
- fix build for <10.1
* Wed May 31 2006 adrian@suse.de
- update to version 1.3.3.2 "stable usable development version"
  * more than 200 bugs and feature requests got implemented
  * fix for pdf export using Adobe Reader 7.x
  * new language translations
* Mon May 29 2006 schwab@suse.de
- Don't strip binaries.
* Mon Feb 20 2006 sbrabec@suse.cz
- Export dynamic symbols from scribus binary (#148279).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Tue Jan 10 2006 sbrabec@suse.cz
- Re-enabled desktop file translation.
* Fri Jan  6 2006 sbrabec@suse.cz
- Updated to version 1.2.4.1.
* Thu Jan  5 2006 sbrabec@suse.cz
- Updated to version 1.2.4.
* Tue Jan  3 2006 sbrabec@suse.cz
- Suggest AdobeICCProfiles.
* Wed Dec  7 2005 sbrabec@suse.cz
- Search for ICC profiles in subdirectories.
  http://bugs.scribus.net/view.php?id=2882
* Fri Nov 25 2005 sbrabec@suse.cz
- Fixed devel splitting (#117811).
- Resource /usr/local/share/color/icc.
  http://bugs.scribus.net/view.php?id=2864
- Enabled parallel build.
* Tue Oct 25 2005 sbrabec@suse.cz
- Updated to version 1.2.3.
- Install MIME info files.
* Wed Jul 27 2005 sbrabec@suse.cz
- Provide and obsolete scribus-short-words.
* Wed Jul 13 2005 sbrabec@suse.cz
- Updated to version 1.2.2.1.
- Removed unneeded static modules and .la files for modules.
* Wed Jan 26 2005 sbrabec@suse.cz
- Obsoleted old documentation packages.
* Tue Jan 11 2005 sbrabec@suse.cz
- Updated to version 1.2.1.
* Thu Dec 16 2004 coolo@suse.de
- fix unsermake install
* Wed Sep 15 2004 sbrabec@suse.cz
- Worked-around bi-arch bugs by forcing /usr/lib (#44961).
  http://bugs.scribus.net/bug_view_advanced_page.php?bug_id=0001057
* Sun Sep  5 2004 coolo@suse.de
- fixing build requires
* Tue Aug 31 2004 sbrabec@suse.cz
- Updated to version 1.2.
* Fri Aug 27 2004 sbrabec@suse.cz
- Updated to version 1.2RC1.
* Wed Mar 31 2004 ro@suse.de
- run update_admin to get current libtool macros
- some more configure hackery to adapt to updated kde-macros
  to finally find python on lib64 platforms
* Wed Mar 31 2004 sf@suse.de
- add scribus-1.1.5-c++.diff (#37208)
* Tue Mar 30 2004 sbrabec@suse.cz
- Updated to version 1.1.6.
* Thu Mar  4 2004 sbrabec@suse.cz
- Updated to version 1.1.5.
* Mon Feb 23 2004 sbrabec@suse.cz
- Fixed and turned on CUPS support.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 sbrabec@suse.cz
- Updated to version 1.0.1.
* Fri Aug 15 2003 adrian@suse.de
- install desktop file
* Wed Aug 13 2003 ro@suse.de
- run update_admin (autoreconf in kde-style)
- change prefix/lib to libdir in all Makefile.am
* Tue Aug 12 2003 sbrabec@suse.cz
- Updated to version 1.0.
* Wed Jun 11 2003 ro@suse.de
- add doc-dir to filelist
* Mon Mar 31 2003 ro@suse.de
- fix build on lib64
* Mon Feb 10 2003 sbrabec@suse.cz
- Fix Qt path for biarch.
* Mon Feb 10 2003 sbrabec@suse.cz
- Updated to version 0.9.7.
* Wed Nov 20 2002 sbrabec@suse.cz
- Added new package.
- FHS fixes.
- Aufoconf fixes.
- KDE autoconf fixes.
